(* pselbutton.mli     Buttons for Psellos apps
 *
 * Copyright (c) 2022 Psellos   http://psellos.com
 *
 * Licensed under the MIT license:
 *     http://opensource.org/licenses/MIT
 *)
open Js_of_ocaml

type t

type state =
    (* State of the button.
     *)
    | Normal   (* Mouse is off somewhere else as far as we know *)
    | OverDown (* Mouse is over the button with mouse button down *)
    | Disabled (* Button is unresponsive *)

type bg =
    | Img of string           (* E.g., Img "img/bpx-blue-308.png" *)
    | Color of CSS.Color.js_t

val create : unit -> t
val element : t -> Dom_html.buttonElement Js.t
val width : t -> float
val set_width : t -> float -> unit
val height : t -> float
val set_height : t -> float -> unit
val set_inner : t -> Dom.node Js.t list -> unit
val set_look : t -> state -> (unit -> unit) -> bg -> unit
val set_topleft : t -> float -> float -> unit
val set_onclick : t -> (Dom_html.mouseEvent Js.t -> bool) option -> unit
val set_disabled : t -> bool -> unit
